from distutils.core import setup

setup(
    name       = 'andy_nester',
    version    = '1.0.0',
    py_modules = ['andy_nester'],
    author     = 'hfpython',
    author_email = 'neolithe@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
)
